@@ -28,7 +28,7 @@ from .parameterized import Parameterized, Parameter, String, \
 from .parameterized import logging_level # pyflakes:ignore (needed for eval)
 from .parameterized import shared_parameters # pyflakes:ignore (needed for eval)
 
-try: 
+try:
    from collections import OrderedDict
 except ImportError:
     from ordereddict import OrderedDict
@@ -41,10 +41,10 @@ except ImportError as e:
 # only two required files.
 try:
     from .version import Version
-    __version__ = Version(release=(1,5,0), fpath=__file__,
-                          commit="7f1db3f", reponame="param")
+    __version__ = Version(release=(1,5,1), fpath=__file__,
+                          commit="4580cce", reponame="param")
 except:
-    __version__ = '1.5.0-unknown'
+    __version__ = '1.5.1-unknown'
 
 
 dt_types = (dt.datetime,)
@@ -615,7 +615,7 @@ class Number(Dynamic):
         super(Number,self).__set__(obj,val)
 
 
-    # Allow softbounds to be used like a normal attribute, as it 
+    # Allow softbounds to be used like a normal attribute, as it
     # probably should have been already (not _softbounds)
     @property
     def softbounds(self): return self._softbounds
@@ -1054,7 +1054,7 @@ class ObjectSelector(Selector):
 
         if not (val in self.objects):
            self.objects.append(val)
-         
+
     def __set__(self,obj,val):
         if self.check_on_set:
             self._check_value(val,obj)
@@ -1092,16 +1092,20 @@ class ClassSelector(Selector):
 
     def _check_value(self,val,obj=None):
         """val must be None, an instance of self.class_ if self.is_instance=True or a subclass of self_class if self.is_instance=False"""
+        if isinstance(self.class_, tuple):
+            class_name = ('(%s)' % ', '.join(cl.__name__ for cl in self.class_))
+        else:
+            class_name = self.class_.__name__
         if self.is_instance:
             if not (isinstance(val,self.class_)) and not (val is None and self.allow_None):
                 raise ValueError(
                     "Parameter '%s' value must be an instance of %s, not '%s'" %
-                    (self._attrib_name, self.class_.__name__, val))
+                    (self._attrib_name, class_name, val))
         else:
             if not (val is None and self.allow_None) and not (issubclass(val,self.class_)):
                 raise ValueError(
                     "Parameter '%s' must be a subclass of %s, not '%s'" %
-                    (val.__name__, self.class_.__name__, val.__class__.__name__))
+                    (val.__name__, class_name, val.__class__.__name__))
 
 
     def __set__(self,obj,val):
@@ -1484,7 +1488,7 @@ class ListSelector(ObjectSelector):
     def _ensure_value_is_in_objects(self,val):
         for o in val:
             super(ListSelector, self)._ensure_value_is_in_objects(o)
-         
+
 
 class MultiFileSelector(ListSelector):
     """
